##  Reviewing Import History
Admin users can download the Changelog from the administration section. The changelog lists all the changes, including the changes made through importing. To download the changelog, do the following:
  1. In the administration area, open the Export section.
  2. Under the Create New Export tab, select Changelog.
  3. Provide the dates for which you need the changelog.
  4. Click Create and Download.


![Downloading Changelog](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio5d7356f525fa4eb7afdbe65fcb7b2ba2_LowRes.png)
Downloading Changelog
Additionally, in the Last Update tab of the fact sheet, you can review the update log to see what changes have been made to a particular fact sheet. To learn more, see [Reviewing the Fact Sheet Update Log](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__reviewing_the_fact_sheet_update_log).
